@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use strictures 2;
 use AI::Prolog ();
@@ -209,7 +209,7 @@ sub _build__database {
         for my $j (sort keys %$list) {
             # get the notes of the base note mode or scale
             my @notes = get_scale_notes($base, $j);
-            warn "Basics: $base $j [@notes]\n" if $self->verbose;
+#            warn "Basics: $base $j [@notes]\n" if $self->verbose;
 
             my @pitches; # notes suitable for the prolog database
 
@@ -246,7 +246,6 @@ sub _build__database {
     }
     # append the prolog rules
     $database .= <<'RULES';
-% Can a chord in one key function in a second?
 pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman, Key2Note, Key2, Key2Function, Key2Roman) :-
     % bind the chord to the function of the first key
     chord_key(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman),
@@ -255,13 +254,12 @@ pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman, Key2
     % the functions cannot be the same
     Key1Function \= Key2Function.
 
-% TODO
 roman_key(Mode, ModeRoman, Key, KeyRoman) :-
     chord_key(_, _, _, Mode, ModeFunction, ModeRoman),
     chord_key(_, _, _, Key, KeyFunction, KeyRoman),
     ModeFunction \= KeyFunction.
 RULES
-    warn "Database: $database\n" if $self->verbose;
+#    warn "Database: $database\n" if $self->verbose;
 
     return $database;
 }
@@ -327,6 +325,7 @@ sub _querydb {
     my @return;
 
     while (my $result = $self->_prolog->results) {
+#warn __PACKAGE__,' L',__LINE__,' ',,"R: @$result\n";
         if ($self->hash_results) {
             my %result;
             @result{ @{ $self->$attr } } = @$result;
@@ -354,7 +353,7 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -403,6 +402,18 @@ version 0.0500
   #  ... ]
   # Inspecting all the results, we see that the answers are D Dorian, D Ionian, and D Mixolydian.
 
+  # compare non-modal scales
+  $m = Music::ModalFunction->new(
+      mode_note  => 'c',
+      mode       => 'diminished',
+      key_note   => 'c',
+      key        => 'harmonic_minor',
+      use_scales => 1,
+  );
+  $results = $m->pivot_chord_keys;
+  # [ 'pivot_chord_keys', 'd', 'dim', 'c', 'diminished', 'flat2', 'r_bII', 'c', 'harmonic_minor', 'supertonic', 'r_ii' ],
+  # [ 'pivot_chord_keys', 'b', 'dim', 'c', 'diminished', 'leading_tone', 'r_vii', 'c', 'harmonic_minor', 'subtonic', 'r_vii' ],
+
 =head1 DESCRIPTION
 
 C<Music::ModalFunction> allows querying of a musical database of
